@@ -1,6 +1,13 @@
 /* GdkPixbuf RGBA C-Source image dump */
 
-static const guint8 add_pixbuf[] = 
+#ifdef __SUNPRO_C
+#pragma align 4 (add_24_rgba)
+#endif
+#ifdef __GNUC__
+static const guint8 add_24_rgba[] __attribute__ ((__aligned__ (4))) = 
+#else
+static const guint8 add_24_rgba[] = 
+#endif
 { ""
   /* Pixbuf magic (0x47646b50) */
   "GdkP"
@@ -113,7 +120,14 @@ static const guint8 add_pixbuf[] =
 
 /* GdkPixbuf RGBA C-Source image dump */
 
-static const guint8 extract_pixbuf[] = 
+#ifdef __SUNPRO_C
+#pragma align 4 (extract_24_rgba)
+#endif
+#ifdef __GNUC__
+static const guint8 extract_24_rgba[] __attribute__ ((__aligned__ (4))) = 
+#else
+static const guint8 extract_24_rgba[] = 
+#endif
 { ""
   /* Pixbuf magic (0x47646b50) */
   "GdkP"
@@ -225,7 +239,14 @@ static const guint8 extract_pixbuf[] =
 
 /* GdkPixbuf RGBA C-Source image dump */
 
-static const guint8 view_pixbuf[] = 
+#ifdef __SUNPRO_C
+#pragma align 4 (view_24_rgba)
+#endif
+#ifdef __GNUC__
+static const guint8 view_24_rgba[] __attribute__ ((__aligned__ (4))) = 
+#else
+static const guint8 view_24_rgba[] = 
+#endif
 { ""
   /* Pixbuf magic (0x47646b50) */
   "GdkP"
@@ -349,7 +370,14 @@ static const guint8 view_pixbuf[] =
 
 /* GdkPixbuf RGBA C-Source image dump */
 
+#ifdef __SUNPRO_C
+#pragma align 4 (folder_rgba)
+#endif
+#ifdef __GNUC__
+static const guint8 folder_rgba[] __attribute__ ((__aligned__ (4))) = 
+#else
 static const guint8 folder_rgba[] = 
+#endif
 { ""
   /* Pixbuf magic (0x47646b50) */
   "GdkP"
@@ -449,7 +477,14 @@ static const guint8 folder_rgba[] =
 
 /* GdkPixbuf RGBA C-Source image dump */
 
+#ifdef __SUNPRO_C
+#pragma align 4 (file_rgba)
+#endif
+#ifdef __GNUC__
+static const guint8 file_rgba[] __attribute__ ((__aligned__ (4))) = 
+#else
 static const guint8 file_rgba[] = 
+#endif
 { ""
   /* Pixbuf magic (0x47646b50) */
   "GdkP"
